package com.bergerkiller.bukkit.nolagg;

import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;
import org.bukkit.permissions.PermissionDefault;

import com.bergerkiller.bukkit.common.permissions.IPermissionDefault;
import com.bergerkiller.bukkit.common.permissions.NoPermissionException;

public enum Permission implements IPermissionDefault {
	
	CLEAR("nolagg.clear", PermissionDefault.OP, "Allows a player to clear all entities on the server"),
	GC("nolagg.gc", PermissionDefault.OP, "Allows a player to garbage collect the server memory"),
	MONITOR("nolagg.monitor", PermissionDefault.OP, "Allows a player to monitor server stats"),
	LOG("nolagg.log", PermissionDefault.OP, "Allows a player to toggle server stats being written to a log file"),
	CLEARLOG("nolagg.clearlog", PermissionDefault.OP, "Allows a player to clear the NoLagg log file"),
	SHOWTICKRATE("nolagg.showtickrate", PermissionDefault.TRUE, "Allows a player to see the tick rate of the server"),
	SHOWMEMORY("nolagg.showmemory", PermissionDefault.OP, "Allows a player to see the current memory usage of the server"),
	FIX("nolagg.fix", PermissionDefault.OP, "Allows a player to fix lighting issues in chunks around him"),
	RELOAD("nolagg.reload", PermissionDefault.OP, "Allows a player to reload NoLagg(Chunks) configuration"),
	EXAMINE("nolagg.examine", PermissionDefault.OP, "Allows a player to generate a new examination file that can be viewed externally");
	
	private Permission(final String path, final PermissionDefault def, final String desc) {
		this.path = path;
		this.def = def;
		this.desc = desc;
	}
	
	public void handle(CommandSender sender) throws NoPermissionException {
		if (sender instanceof Player) {
			if (!((Player) sender).hasPermission(this.path)) throw new NoPermissionException();
		}
	}
	
	private final String path;
	private final PermissionDefault def;
	private final String desc;

	@Override
	public String getName() {
		return this.path;
	}

	@Override
	public PermissionDefault getDefault() {
		return this.def;
	}

	@Override
	public String getDescription() {
		return this.desc;
	}

}
